/*
Copyright (c) 2003-2016, CKSource - Frederico Knabben. All rights reserved.
For licensing, see LICENSE.md or http://ckeditor.com/license
*/
CKEDITOR.plugins.setLang( 'mathjax', 'sv', {
	title: 'Mattematik i TeX',
	button: 'Matte',
	dialogInput: 'Skriv din TeX här',
	docUrl: 'http://en.wikibooks.org/wiki/LaTeX/Mathematics',
	docLabel: 'TeX dokumentation',
	loading: 'laddar...',
	pathName: 'matte'
} );
